import {getCars} from './getCars';

import {generateReport} from './generateReport';

import {
  select,
  csv,
  scaleLinear,
  max,
  extent,
  axisLeft,
  axisBottom,
  format,
  scaleTime,
  area,
  curveBasis //pre zaoblovanie ciary
	} from 'd3' //importujeme potrebne fcie z d3
const svg=select('svg');
const width=+svg.attr('width');
const height=+svg.attr('height');


const render = data=>{
  
  const xValue=d=>d.year;
  const yValue=d=>d.population;
  const circleRadius=7;
  const xAxisLabel='Year';
  const yAxisLabel='Population';
  const graphTitle='World population';
  const margin={top:50,bottom:60,left:80,right:40};
  const innerWidth=width-margin.left-margin.right;
  const innerHeight=height-margin.top-margin.bottom;
  
  const xScale=scaleTime() //instance of scale linear
    .domain(extent(data,xValue)) //extent vracia pole -min,max range
    .range([0,innerWidth])
     .nice();
  
 
  const g =svg.append('g')//group element
    .attr('transform',`translate(${margin.left},${margin.top})`);
  
  
  
  
  const yScale=scaleLinear()
  	 .domain([0,max(data,yValue)])
    .range([innerHeight,0])
    .nice();
  
  const yAxisTickFormat=number=>format('.1s')(number)//1s=1 significant digit
     .replace('G','B');
  
  const xAxis=axisBottom(xScale)
  		//.tickFormat(xAxisTickFormat)
      .ticks(8)
      .tickSize(-innerHeight)
      .tickPadding(12);
  
  const yAxis=axisLeft(yScale)
   .tickFormat(yAxisTickFormat)
   .tickSize(-innerWidth)
    .tickPadding(10);
  
   const areaGenerator=area()
   .x(d=>xScale(xValue(d)))
   .y0(innerHeight)
   .y1(d=>yScale(yValue(d)))
   .curve(curveBasis);//spline-smmothing
  
  g.append('path')
   .attr('d',areaGenerator(data))
   .attr('class','line-path');
 
  const yAxisG=g.append('g').call(yAxis);
  	//.selectAll('.domain,.tick line') //dodatocne zmazanie ciary vert. osi
   // .remove();
  
   yAxisG.append('text')//popis vodorovnej osi
  .attr('class','axis-label')//aby sme to vedeli vyselektovat pre styling
  .attr('y',-50)
  .attr('x',-innerHeight/2)
  .attr('fill','black')
  .text(yAxisLabel)
  .attr('transform',`rotate(-90)`)
  .attr('text-anchor','middle');
  
  const xAxisG= g.append('g').call(xAxis)
    .attr('transform',`translate(0,${innerHeight})`);
  xAxisG
    .select('.domain')
    .remove();
  xAxisG.append('text')//popis vodorovnej osi
  .attr('class','axis-label')//aby sme to vedeli vyselektovat pre styling
  .attr('y',60)
  .attr('x',innerWidth/2)
  .attr('fill','black')
  .text(xAxisLabel);
  
 /* // nepotrebujeme uz robit data join, staci nam append path
  g.selectAll('circle').data(data)
    .enter().append('circle')
    .attr('cy',d=>yScale(yValue(d)))
    .attr('cx',d=>xScale(xValue(d)))
    .attr('r',circleRadius)
  */
 
  g.append('text')
  .attr('y',-10)
  .attr('text-anchor','middle')//vystredenie horizontalne
  .attr('x',innerWidth/2)
  .text(graphTitle);//nadpis

};
 

csv('https://vizhub.com/curran/datasets/world-population-by-year-2015.csv')
  .then(data =>{
   data.forEach(d =>{
                d.population=+d.population; //zmena na cislo
                d.year=new Date(d.year);
      					
   });
    render(data);
});





